/*********************************************************************
*                    SEGGER Microcontroller GmbH                     *
*        Solutions for real time microcontroller applications        *
**********************************************************************
*                                                                    *
*        (c) 1996 - 2018  SEGGER Microcontroller GmbH                *
*                                                                    *
*        Internet: www.segger.com    Support:  support@segger.com    *
*                                                                    *
**********************************************************************

** emWin V5.48 - Graphical user interface for embedded applications **
emWin is protected by international copyright laws.   Knowledge of the
source code may not be used to write a similar product.  This file may
only  be used  in accordance  with  a license  and should  not be  re-
distributed in any way. We appreciate your understanding and fairness.
----------------------------------------------------------------------
File        : GUI_DrawExternalImage_BMP.c
Purpose     : Sample that shows how to draw external BMP images
              with emWin.
              This sample supports both usage in the Windows Simulation as well
              as usage on a target device using emFile.
---------------------------END-OF-HEADER------------------------------
*/
#include "project.h"
#include <stddef.h>
#include <string.h>
#include "WIDGET.h"
#include "WM.h"
#include "BUTTON.h"
#include "DIALOG.h"
#include "FS.h"


#define RECOMMENDED_MEMORY (1024L * 5)
/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define ID_WINDOW_0    (GUI_ID_USER + 0x00)

extern void CreateToolsScreen();
extern void DrawBMPExternalMemory();

/*********************************************************************
*
*       Public code
*
**********************************************************************
*/
int _Pressed = 0;
#define ID_BUTTON  1
unsigned int ArrowLeft = 21;
unsigned int ArrowRight = 100;

/*********************************************************************
*
*       Static data
*
**********************************************************************
*/
/*********************************************************************
*
*       _aDialogCreate
*/
static const GUI_WIDGET_CREATE_INFO _aDialogCreate[] = 
{
  { WINDOW_CreateIndirect, "Window", ID_WINDOW_0, 0,  0, 320, 240, 0, 0x0, 0},
  { TEXT_CreateIndirect, "ArrowTextLeft", GUI_ID_TEXT0, 40, 35, 35, 20, 0, 0x64, 0 },
  { TEXT_CreateIndirect, "ArrowTextRight", GUI_ID_TEXT1, 245, 35, 35, 20, 0, 0x64, 0 },
  { BUTTON_CreateIndirect, "UpArrow1", GUI_ID_BUTTON0, 5, 10, 35, 35, 0, 0, 0 },
  { BUTTON_CreateIndirect, "DownArrow1", GUI_ID_BUTTON1, 5, 45, 35, 35, 0, 0, 0 },
  { BUTTON_CreateIndirect, "UpArrow2", GUI_ID_BUTTON2, 290, 10, 35, 35, 0, 0, 0 },
  { BUTTON_CreateIndirect, "DownArrow2", GUI_ID_BUTTON3, 290, 45, 35, 35, 0, 0, 0 },
  { IMAGE_CreateIndirect, "LowAlarmIcon", GUI_ID_IMAGE2, 40, 0, 25, 35, 0, 0, 0 },
  { IMAGE_CreateIndirect, "HighAlarmIcon", GUI_ID_IMAGE3, 250, 0, 25, 35, 0, 0, 0 },
//  { TEXT_CreateIndirect, "ArrowTextLeft", GUI_ID_TEXT0, 5, 35, 35, 20, 0, 0x64, 0 },
//  { TEXT_CreateIndirect, "ArrowTextRight", GUI_ID_TEXT1, 280, 35, 35, 20, 0, 0x64, 0 },
//  { BUTTON_CreateIndirect, "UpArrow1", GUI_ID_BUTTON0, 45, 10, 35, 35, 0, 0, 0 },
//  { BUTTON_CreateIndirect, "DownArrow1", GUI_ID_BUTTON1, 45, 45, 35, 35, 0, 0, 0 },
//  { BUTTON_CreateIndirect, "UpArrow2", GUI_ID_BUTTON2, 250, 10, 35, 35, 0, 0, 0 },
//  { BUTTON_CreateIndirect, "DownArrow2", GUI_ID_BUTTON3, 250, 45, 35, 35, 0, 0, 0 },
//  { IMAGE_CreateIndirect, "LowAlarmIcon", GUI_ID_IMAGE2, 5, 0, 25, 35, 0, 0, 0 },
//  { IMAGE_CreateIndirect, "HighAlarmIcon", GUI_ID_IMAGE3, 285, 0, 25, 35, 0, 0, 0 },
  { BUTTON_CreateIndirect, "Brightness", GUI_ID_BUTTON4, 10, 193, 40, 40, 0, 0, 0 },
  { BUTTON_CreateIndirect, "Tools", GUI_ID_BUTTON5, 50, 193, 40, 40, 0, 0, 0 },
  { BUTTON_CreateIndirect, "Lock", GUI_ID_BUTTON6, 90, 193, 40, 40, 0, 0, 0 },
  { IMAGE_CreateIndirect, "BatteryCharging", GUI_ID_IMAGE0, 178, 195, 24, 38, 0, 0, 0 },
  { IMAGE_CreateIndirect, "ExternalPower", GUI_ID_IMAGE1, 206, 195, 24, 38, 0, 0, 0 },

  { BUTTON_CreateIndirect, "Alarm", GUI_ID_BUTTON7, 237, 193, 40, 40, 0, 0, 0 },
  { TEXT_CreateIndirect, "AlarmSilenceTime", GUI_ID_TEXT2, 280, 205, 35, 20, 0, 0x64, 0 },
  { TEXT_CreateIndirect, "OxygenPercentage", GUI_ID_TEXT3, 90, 85, 110, 75, 0, 0x64, 0 },

};


/*********************************************************************
*       UpArrowLeft Callback
**********************************************************************/
static void _cbUpArrow(WM_MESSAGE * pMsg) 
{
    switch (pMsg->MsgId) 
    {
        case WM_PAINT:
            DrawBMPExternalMemory("UpArrowUp.bmp");
        break;
        default:
            BUTTON_Callback(pMsg); // The original callback
        break;
    }
 
}
/*********************************************************************
*       DownArrowLeft Callback
**********************************************************************/
static void _cbDownArrow(WM_MESSAGE * pMsg) 
{
    switch (pMsg->MsgId) 
    {
        case WM_PAINT:
            DrawBMPExternalMemory("DownArrowUp.bmp");
        break;
        default:
            BUTTON_Callback(pMsg); // The original callback
        break;
    }
 
}
/*********************************************************************
*       ButtonBacklight Callback
**********************************************************************/
static void _cbButtonBacklight(WM_MESSAGE * pMsg) 
{
    switch (pMsg->MsgId) 
    {
        case WM_PAINT:
        
            if(BUTTON_IsPressed(pMsg->hWin))
            {
                DrawBMPExternalMemory("ButtonBacklightDown.bmp");
            }
            else
            {
                DrawBMPExternalMemory("ButtonBacklightUp.bmp");
            }
            
        break;
        default:
            BUTTON_Callback(pMsg); // The original callback
        break;
    }
 
}

///*********************************************************************
//*       Tools Callback
//**********************************************************************/
static void _cbTools(WM_MESSAGE * pMsg) 
{
    switch (pMsg->MsgId) 
    {
        case WM_PAINT:
            if(BUTTON_IsPressed(pMsg->hWin))
            {
                DrawBMPExternalMemory("GearDown.bmp");
            }
            else
            {
                DrawBMPExternalMemory("GearUp.bmp");
            }
        break;
        default:
            BUTTON_Callback(pMsg); // The original callback
        break;
    }
 
}
/*********************************************************************
*       Lock Callback
**********************************************************************/
static void _cbLock(WM_MESSAGE * pMsg) 
{
    switch (pMsg->MsgId) 
    {
        case WM_PAINT:
            if(BUTTON_IsPressed(pMsg->hWin))
            {
                DrawBMPExternalMemory("LockDown.bmp");
            }
            else
            {
                DrawBMPExternalMemory("LockUp.bmp");
            }
        break;
        default:
            BUTTON_Callback(pMsg); // The original callback
        break;
    }
 
}

/*********************************************************************
*       BatteryCharging Callback
**********************************************************************/
static void _cbBatteryCharging(WM_MESSAGE * pMsg) 
{
    switch (pMsg->MsgId) 
    {
        case WM_PAINT:
            DrawBMPExternalMemory("BatteryCharging.bmp");
        break;
        default:
            BUTTON_Callback(pMsg); // The original callback
        break;
    }
 
}
/*********************************************************************
*       ExternalPower Callback
**********************************************************************/
static void _cbExternalPower(WM_MESSAGE * pMsg) 
{
    switch (pMsg->MsgId) 
    {
        case WM_PAINT:
            DrawBMPExternalMemory("ExternalPower.bmp");
        break;
        default:
            BUTTON_Callback(pMsg); // The original callback
        break;
    }
 
}
/*********************************************************************
*       AlarmSilence Callback
**********************************************************************/
static void _cbAlarmSilence(WM_MESSAGE * pMsg) 
{
    switch (pMsg->MsgId) 
    {
        case WM_PAINT:
            if(BUTTON_IsPressed(pMsg->hWin))
            {
                DrawBMPExternalMemory("AlarmNoSilenceIconDown.bmp");
            }
            else
            {
                DrawBMPExternalMemory("AlarmNoSilenceIconUp.bmp");
            }
        break;
        default:
            BUTTON_Callback(pMsg); // The original callback
        break;
    }
 
}   
/*********************************************************************
*      Low Alarm Icon Callback
**********************************************************************/
static void _cbLowAlarmIcon(WM_MESSAGE * pMsg) 
{
    switch (pMsg->MsgId) 
    {
        case WM_PAINT:
            DrawBMPExternalMemory("LowAlarmIcon.bmp");
        break;
        default:
            BUTTON_Callback(pMsg); // The original callback
        break;
    }
 
} 
/*********************************************************************
*     High  Alarm Icon Callback
**********************************************************************/
static void _cbHighAlarmIcon(WM_MESSAGE * pMsg) 
{
    switch (pMsg->MsgId) 
    {
        case WM_PAINT:
            DrawBMPExternalMemory("HighAlarmIcon.bmp");
        break;
        default:
            BUTTON_Callback(pMsg); // The original callback
        break;
    }
 
} 
/*********************************************************************
*
*       _cbDialog
*/
static void _cbDialog(WM_MESSAGE * pMsg) 
{
//    static WM_HWIN hWin;
    WM_HWIN      hItem;
    int          NCode;
    int          Id;
    BUTTON_Handle hButton;
    TEXT_Handle hText;
    TEXT_Handle hText1;
    TEXT_Handle hText2;
    
    int X0 = 160;    
    int Y0 = 120;
    float XR = 84.5;
    float YR = 84.5;
    float aend = 0;
    float astart = 0;
    int OxygenValue = 21;
    int i = 0;
    float  ae30 = 186.3, as30 = 189.57;
    float  ae40 = 153.6, as40 = 156.87;
    float  ae50 = 120.9, as50 = 124.17;
    float  ae60 = 88.2, as60 = 93.0;
    float  ae70 = 55.5, as70 = 58.77;
    float  ae80 = 22.8, as80 = 26.07;
    float  ae90 = -9.9, as90 = -6.63;
  
    hItem = pMsg -> hWin;
    switch (pMsg->MsgId) 
    {
        case WM_PAINT:
        
            GUI_SetColor(0x00DBA47B);
            GUI_SetPenSize(1); 
            GUI_DrawLine(0,188, 320,188);
            GUI_DrawRect(175,190, 315,238);
            GUI_DrawLine(230, 190, 230, 237);
            GUI_SetColor(0x00774409);
            GUI_SetPenSize(3);
            GUI_DrawLine(5, 177, 90, 177);
            GUI_DrawLine(230, 177, 315, 177);
            GUI_SetFont(GUI_FONT_24B_1);
            GUI_SetColor(0x00400000);
            GUI_DispStringAt("21",5,150);
            GUI_DispStringAt("100",280,150); 
            GUI_SetFont(GUI_FONT_32B_ASCII);
            GUI_DispStringAt("%" , 205, 95);
            
            for(i =0; i<80; i++)
            {
                
                astart = (-3.2658* OxygenValue) + 287.67;
                aend = astart - 3.2658;

                GUI_SetPenSize( 17 );
                GUI_SetTextMode(GUI_TM_TRANS);
                GUI_SetFont(&GUI_FontComic18B_ASCII);
                
                if(OxygenValue < 30)
                {                    
                    GUI_SetColor( GUI_BLUE_ARC1);
                    GUI_DrawArc(X0, Y0, XR, YR, aend, astart);
                    
                }
                else if(OxygenValue <40)
                {
                    if(OxygenValue > 30)
                    {
                        GUI_SetColor( GUI_BLUE_ARC2);
                        GUI_DrawArc(X0, Y0, XR, YR, aend, astart);
                    }
                }
                else if(OxygenValue <50)
                {
                    if(OxygenValue > 40)
                    {
                        GUI_SetColor( GUI_BLUE_ARC3);
                        GUI_DrawArc(X0, Y0, XR, YR, aend, astart);
                    }
                }                
                else if(OxygenValue <60)
                {
                    if(OxygenValue > 50)
                    {
                        GUI_SetColor( GUI_BLUE_ARC4);
                        GUI_DrawArc(X0, Y0, XR, YR, aend, astart);
                    }
                }                     
                else if(OxygenValue <70)
                {
                    if(OxygenValue > 60)
                    {
                        GUI_SetColor( GUI_GREEN_ARC1);
                        GUI_DrawArc(X0, Y0, XR, YR, aend, astart);
                    }
                } 
                else if(OxygenValue <80)
                {
                    if(OxygenValue > 70)
                    {
                        GUI_SetColor( GUI_GREEN_ARC2);
                        GUI_DrawArc(X0, Y0, XR, YR, aend, astart);
                    }
                }                 
                else if(OxygenValue <90)
                {
                    if(OxygenValue > 80)
                    {
                        GUI_SetColor( GUI_GREEN_ARC3);
                        GUI_DrawArc(X0, Y0, XR, YR, aend, astart);
                    }
                } 
                else if(OxygenValue <100)
                {
                    if(OxygenValue > 90)
                    {
                        GUI_SetColor( GUI_GREEN_ARC4);
                        GUI_DrawArc(X0, Y0, XR, YR, aend, astart);
                    }
                } 
                else                 
                {
                    GUI_SetColor(GUI_BEIGE_BACKGROUND);
                    GUI_DrawArc(X0, Y0, XR, YR, ae30, as30);
                    GUI_DrawArc(X0, Y0, XR, YR, ae40, as40);
                    GUI_DrawArc(X0, Y0, XR, YR, ae50, as50);
                    GUI_DrawArc(X0, Y0, XR, YR, ae60, as60);
                    GUI_DrawArc(X0, Y0, XR, YR, ae70, as70);
                    GUI_DrawArc(X0, Y0, XR, YR, ae80, as80);
                    GUI_DrawArc(X0, Y0, XR, YR, ae90, as90);                 

                }
                OxygenValue++;
            }
                 
        break;

        case WM_INIT_DIALOG:

            WINDOW_SetBkColor(hItem, GUI_MAKE_COLOR(GUI_BEIGE_BACKGROUND));
                      
            hText = WM_GetDialogItem(pMsg->hWin, GUI_ID_TEXT0); // Initialization of 'Text box left'
            TEXT_SetFont(hText, GUI_FONT_24B_1);
            TEXT_SetTextColor(hText, 0x00400000);
            TEXT_SetText(hText, "21");
            
            hText = WM_GetDialogItem(pMsg->hWin, GUI_ID_TEXT1); // Initialization of 'Text box right'
            TEXT_SetFont(hText, GUI_FONT_24B_1);
            TEXT_SetText(hText, "100");          
            
            hButton = WM_GetDialogItem(pMsg->hWin, GUI_ID_BUTTON0); // Initialization of 'UpArrowLeft'
            WM_SetCallback(hButton, _cbUpArrow);

            hButton = WM_GetDialogItem(pMsg->hWin, GUI_ID_BUTTON1);// Initialization of 'DownArrowLefy'
            WM_SetCallback(hButton, _cbDownArrow);
            
            hButton = WM_GetDialogItem(pMsg->hWin, GUI_ID_BUTTON2);// Initialization of 'UpArrowRight'
            WM_SetCallback(hButton, _cbUpArrow);
            
            hButton = WM_GetDialogItem(pMsg->hWin, GUI_ID_BUTTON3);// Initialization of 'DownArrowRight'
            WM_SetCallback(hButton, _cbDownArrow);

            hButton = WM_GetDialogItem(pMsg->hWin, GUI_ID_BUTTON4);// Initialization of 'ButtonBacklight'
            WM_SetCallback(hButton, _cbButtonBacklight);
                        
            hButton = WM_GetDialogItem(pMsg->hWin, GUI_ID_BUTTON5);// Initialization of 'Tools'
            WM_SetCallback(hButton, _cbTools);
            
            hButton = WM_GetDialogItem(pMsg->hWin, GUI_ID_BUTTON6);// Initialization of 'Lock'
            WM_SetCallback(hButton, _cbLock);      
            
            hButton = WM_GetDialogItem(pMsg->hWin, GUI_ID_IMAGE0);// Initialization of 'BatteryCharging'
            WM_SetCallback(hButton, _cbBatteryCharging);
            
            hButton = WM_GetDialogItem(pMsg->hWin, GUI_ID_IMAGE1);// Initialization of 'ExternalPower'
            WM_SetCallback(hButton, _cbExternalPower);
            
            hButton = WM_GetDialogItem(pMsg->hWin, GUI_ID_IMAGE2);// Initialization of 'LowAlarmIcon'
            WM_SetCallback(hButton, _cbLowAlarmIcon);
            
            hButton = WM_GetDialogItem(pMsg->hWin, GUI_ID_IMAGE3);// Initialization of 'HighAlarmIcon'
            WM_SetCallback(hButton, _cbHighAlarmIcon);            
            
            hButton = WM_GetDialogItem(pMsg->hWin, GUI_ID_BUTTON7);// Initialization of 'Alarm Silence'
            WM_SetCallback(hButton, _cbAlarmSilence);      
                                    
            hText = WM_GetDialogItem(pMsg->hWin, GUI_ID_TEXT2);// Initialization of 'AlarmSilenceTime' 
            TEXT_SetFont(hText, GUI_FONT_24B_1);
            TEXT_SetText(hText, "120");  
            
            hText = WM_GetDialogItem(pMsg->hWin, GUI_ID_TEXT3);// Initialization of 'Oxygen Percentage' 
            TEXT_SetFont(hText, GUI_FONT_D36X48);
            TEXT_SetText(hText, "100");            
            
            
        break;
            
        case WM_NOTIFY_PARENT:
            Id    = WM_GetId(pMsg->hWinSrc);
            NCode = pMsg->Data.v;
            switch (NCode) 
            {                
                case WM_NOTIFICATION_RELEASED:      // React only if released
                hItem = WM_GetDialogItem(pMsg->hWin, ID_WINDOW_0);
                hText1 = WM_GetDialogItem(pMsg->hWin, GUI_ID_TEXT0);
                hText2 = WM_GetDialogItem(pMsg->hWin, GUI_ID_TEXT1);
                    if(Id == GUI_ID_BUTTON0) // UpArrowLeft
                    {
                        GUI_Clear();
                        ArrowLeft =  (ArrowLeft+1);                        
                        TEXT_SetDec (hText1,ArrowLeft,2,0,0,1);

                    }
                    if(Id == GUI_ID_BUTTON1) // DownArrowLeft
                    {
                        GUI_Clear();
                        ArrowLeft =  (ArrowLeft-1);                        
                        TEXT_SetDec (hText1,ArrowLeft,2,0,0,1);

                    }
                    
                    if(Id == GUI_ID_BUTTON2) // UpArrowRight
                    {
                        GUI_Clear();
                        ArrowRight =  (ArrowRight+1);                        
                        TEXT_SetDec (hText2,ArrowRight,2,0,0,1);

                    }
                    if(Id == GUI_ID_BUTTON3) // DownArrowRight
                    {
                        GUI_Clear();
                        ArrowRight =  (ArrowRight-1);                        
                        TEXT_SetDec (hText2,ArrowRight,2,0,0,1);

                    }
                    if(Id == GUI_ID_BUTTON4) // Brighntess-Up/down
                    {
//                     if(PWM_1_ReadCompare() == 900)
//                    {
//                        PWM_1_WriteCompare(0);
//                    }
//                    else if(PWM_1_ReadCompare() == 0)
//                    {
//                        PWM_1_WriteCompare(300);
//                    }
//                    else if(PWM_1_ReadCompare() == 300)
//                    {
//                        PWM_1_WriteCompare(600);
//                    }
//                    else
//                    {
//                        PWM_1_WriteCompare(900);
//                    }                       

                    }  
                    if(Id == GUI_ID_BUTTON5)// ToolsScreen
                    {
                        GUI_EndDialog(hItem,1);
                        CreateToolsScreen();
                    }
                    

            }
        break;
            

        default:
        WM_DefaultProc(pMsg);  
    }

}

/*********************************************************************
*
*       Public code
*
**********************************************************************
*/
/*********************************************************************
*
*       MainTask
*/
void MainScreen(void) 
{
  if (GUI_ALLOC_GetNumFreeBytes() < RECOMMENDED_MEMORY) {
    GUI_ErrorOut("Not enough memory available."); 
    return;
  }     
    //    
    //    Use memory devices for all windows
    //    
    #if GUI_SUPPORT_MEMDEV
    WM_SetCreateFlags(WM_CF_MEMDEV);
    WM_EnableMemdev(WM_HBKWIN);
    #endif

    WM_SetDesktopColor(GUI_BLACK);

    while (1) 
    {
        GUI_ExecDialogBox(_aDialogCreate, GUI_COUNTOF(_aDialogCreate), &_cbDialog, 0, 0, 0);
  
        GUI_Delay(10);
    }
}

/*************************** End of file ****************************/

